'''
Manage Azure Event Hubs namespaces, eventhubs, consumergroups and geo recovery configurations - Alias
'''
from .. pyaz_utils import _call_az
from . import cluster, eventhub, georecovery_alias, namespace

