'''
Manage Azure Search services, admin keys and query keys.
'''
from .. pyaz_utils import _call_az
from . import admin_key, private_endpoint_connection, private_link_resource, query_key, service, shared_private_link_resource

