'''
Manage and operate Synapse Workspace, Spark Pool, SQL Pool.
'''
from .. pyaz_utils import _call_az
from . import activity_run, data_flow, dataset, integration_runtime, integration_runtime_node, kusto_operation, linked_service, managed_private_endpoints, notebook, pipeline, pipeline_run, spark_job_definition, sql_script, trigger, trigger_run, workspace, workspace_package

