'''
Manage and administer Azure Service Fabric clusters.
'''
from .. pyaz_utils import _call_az
from . import application_type, cluster, managed_application, managed_application_type, managed_cluster, managed_node_type, managed_service, service

