'''
Manage synapse kusto
'''
from ... pyaz_utils import _call_az
from . import attached_database_configuration, data_connection, database, database_principal_assignment, pool, pool_principal_assignment

